@@ -10,8 +10,7 @@ use NewcomDigital\Enum\Enum;
  */
 class TripLinkType extends Enum
 {
+    public const LINE = 'line';
 
-    const LINE = 'line';
-
-    const ROAD = 'road';
+    public const ROAD = 'road';
 }
