@@ -180,6 +180,11 @@ class CampsiteSearchQueryBuilder implements ElasticQueryBuilderInterface
         return $this;
     }
 
+    public function getAdditionalFilters(): array
+    {
+        return $this->filters['additional'];
+    }
+
     /**
      * @param array $thematicIds
      * @param array $campsiteIds
